;=======================
;
; Cars v2.0
;  by Cullen Sauls
;
; Title picture: Ki Jeon Nam
;
; Contact:
;  webpage: http://cullen.macross2000.org
;  e-mail:  sauls@tamu.edu
;  ICQ:     11130342
;  AIM:     OrbitYFL
;
; Copyright  December 2001
;
; Source code looks best in Assembly Studio
;  Use Assembly Studio 8x project function for best results
;
;=======================

#include "ti86asm.inc"
#include "macros.h"

BitTest             = $C100                 ;[8]
Speed               = BitTest+8             ;[1]
TrackSize           = Speed+1               ;[1]
Width               = TrackSize+1           ;[1]
MoveDir             = Width+1               ;[1]    ;-1 = left:1 = right
MoveCount           = MoveDir+1             ;[1]
CarX                = MoveCount+1           ;[1]
Wall                = CarX+1                ;[1]
Score               = Wall+1                ;[2]
ScoreDelay          = Score+2               ;[1]
ExitPress           = ScoreDelay+1          ;[1]
HitWall             = ExitPress+1           ;[1]
Life                = HitWall+1             ;[1]
ShrapnelCoord       = Life+1                ;[2 * 5]    ;5 pieces

SCREENADDR          = $FC00
SCREENSAVE          = $F600
SCORERATE           = 8

.org _asm_exec_ram

    nop
    jp ProgStart
    .dw 1
    .dw ShellTitle
    .dw CarSprite

ShellTitle:
    .db "Cars v2.0 by Cullen Sauls",0

ProgStart:
 call _runindicoff
 call _flushallmenus
 res appTextSave,(iy+appflags)

 call CloseBlinds
 call _clrLCD
 ld hl,TitleScreen
 ld de,SCREENADDR
 call DispRLE
 call _pause

 ld a,2
 ld (Speed),a
 dec a
 ld (TrackSize),a

MenuSetup:
 ld hl,CPBits
 ld de,BitTest
 ld bc,8
 ldir

 call CloseBlinds
 call _clrLCD

 ld hl,MenuText
 ld b,8
 call _VPUTS
 djnz $-3
;
 call GetHighScore
 ex de,hl
 ld hl,_penCol
 inc (hl)
 inc (hl)
 ex de,hl
 call _vputs

 ld a,(hl)
 inc hl
 ld h,(hl)
 ld l,a
 ld de,$3860
 ld b,5
 call DispHL

 ld hl,SCREENADDR
 call InvRow
 ld hl,SCREENADDR+(32*16)
 call InvRow
 ld hl,SCREENADDR+(56*16)
 call InvRow

 ld h,5
 ld l,2
 ld a,(TrackSize)
 or a
 jr nz,$+4
 ld l,10
 call DrawBlock
 ex de,hl

 ld l,6
 ld a,(Speed)
 ld b,a
 ld a,3
 sub b
 ld h,a
 call DrawBlock

; HL = Speed block coords
; DE = Track size block coords
MenuLoop:
 push hl
 push de
 call _getky
 pop de
 pop hl
 or a
 jr z,MenuLoop
 cp K_EXIT
 jp z,ExitGame
 cp K_ENTER
 jr z,DoneMenu
 cp K_SECOND
 jr z,DoneMenu
 push af
 call DrawBlock
 ex de,hl
 call DrawBlock
 ex de,hl
 pop af
 cp K_UP
 call z,DecSpeed
 cp K_DOWN
 call z,IncSpeed
 cp K_LEFT
 call z,ChangeTrackSize
 cp K_RIGHT
 call z,ChangeTrackSize
 call DrawBlock
 ex de,hl
 call DrawBlock
 ex de,hl
 push hl
 push de
 ld hl,SCREENADDR+(56*16)
 ld de,SCREENADDR+(56*16)+1
 ld (hl),$FF
 ld bc,16*7-1
 ldir
 SETWONB
 ld hl,HighScoreText
 call _VPUTS
 call GetHighScore
 ex de,hl
 ld hl,_penCol
 inc (hl)
 inc (hl)
 ex de,hl
 call _vputs
 ld a,(hl)
 inc hl
 ld h,(hl)
 ld l,a
 ld de,$3860
 ld b,5
 call DispHL
 SETBONW
 pop de
 pop hl
 jr MenuLoop
DoneMenu:
 ld a,(TrackSize)
 ld b,a
 add a,3
 add a,a
 add a,a
 add a,a
 ld (Width),a

;variable setup
 ld hl,MoveDir
 ld (hl),1
 inc hl
 ld (hl),1
 inc hl
 ld (hl),60
 inc hl

 ld a,b
 add a,a
 add a,a
 ld b,a
 ld a,52
 sub b
 ld (hl),a
 inc hl
 ld a,$FF
 ld (hl),a
 inc hl
 ld (hl),a
 inc hl
 ld (hl),0

 ld hl,Life
 ld (hl),50

 call CloseBlinds

 call PlaceTopRow

 ld hl,SCREENADDR+(16*7)
 ld de,SCREENADDR+(16*8)
 ld bc,1024-(16*8)
 ldir

 call ShowLife

MainLoop:
;erase the old sprite
 ld a,(CarX)
 ld b,a
 ld c,56
 ld hl,CarSprite+2
 call FastSprite

 ld hl,SCREENADDR+1023-16
 ld de,SCREENADDR+1023
 ld bc,1024-(16*8)
 lddr
 call PlaceTopRow

 ld hl,ScoreDelay
 ld a,(hl)
 dec (hl)
 or a
 jr nz,NoUpdateScore
 ld (hl),SCORERATE
 SETWONB
 ld hl,(Score)
 inc hl
 ld (Score),hl
 ld b,5
 ld de,$006B
 call DispHL
 SETBONW
NoUpdateScore:
 ld hl,MoveCount
 dec (hl)
 ld a,(hl)
 or a
 call z,MoveChange

 ld hl,Wall
 ld a,(MoveDir)
 add a,(hl)

 cp 8
 jr c,SwapDir
 ld b,a
 ld a,(Width)
 add a,b
 cp 120
 ld a,b
 jr nc,SwapDir
 ld (hl),a
 jr DoneUpdate
SwapDir:
 ld hl,MoveDir
 ld a,(hl)
 cpl
 inc a
 ld (hl),a
 inc hl
 ld (hl),8

DoneUpdate:
 call ReadKeys

 xor a
 ld (HitWall),a

 ld a,(CarX)
 ld b,a
 ld a,57
 push af
 push af
 push bc
 call CheckPixel
 call nz,DecreaseLife
 pop bc
 ld a,b
 add a,7
 ld b,a
 pop af
 call CheckPixel
 call nz,DecreaseLife
 pop af
 inc a
 cp 65
 jr nc,$-23

;place new sprite
 ld a,(CarX)
 ld b,a
 ld c,56
 ld hl,CarSprite+2
 call FastSprite

 ld a,(Speed)
 inc a
 ld b,a
 HALT_LOOP

 ld a,(Life)
 cp 100
 jr nc,CarCrash

 ld a,(ExitPress)
 or a
 jp z,MainLoop
EndGame:
 call _getky
 jp MenuSetup
CarCrash:
 ld a,(CarX)
 ld b,a
 ld c,56
 ld hl,CarSprite+2
 call FastSprite

 push bc
 ld hl,SCREENADDR
 ld de,SCREENSAVE
 ld bc,1024
 ldir
 pop bc

 ld d,25
 ld a,r
 rra
 ld h,a
 ld l,a
 call FastSprite
 push bc
 ld b,10
 HALT_LOOP
 pop bc
 dec d
 jr nz,$-16

 ld hl,SCREENSAVE
 ld de,SCREENADDR
 ld bc,1024
 ldir

 set textEraseBelow,(iy+textflags)
 ld hl,CrashText
 call _VPUTS
 res textEraseBelow,(iy+textflags)
 
 call _pause

 call GetHighScore
 push hl
 ld de,9
 add hl,de
 ld a,(hl)
 inc hl
 ld h,(hl)
 ld l,a
 ld de,(Score)
 call _cphlde
 pop de
 jp nc,MenuSetup
;
;High score has been beaten
;
 push de
 ld a,' '
 ld hl,_textShadow+111
 ld (hl),a
 ld b,8
 ld (de),a
 inc de
 djnz $-2
 inc de
 ex de,hl
 ld de,(Score)
 ld (hl),e
 inc hl
 ld (hl),d

 call _clrLCD
 ld hl,NewHSText
 call _PUTS
 call _PUTS
 pop de
 ld hl,$0605
 ld (_curRow),hl
 ld a,' '
 ld (_curUnder),a
 call _putc
 ld (_curRow),hl
 call _cursorOn

 set appTextSave,(iy+appflags)
;
;repeat until [Enter] is pressed
;
GetNameLoop:
 push de
 call _getky
 pop de
 cp K_ENTER
 jr z,SaveTable
 cp K_DEL
 jr z,DeleteChar

 cp K_SIGN
 jr z,SetSpace

 ld hl,KeyLetterTable
 ld bc,27
 cpir

 ld a,c
 or a
 jr z,GetNameLoop

 ld a,(de)
 or a
 jr z,GetNameLoop

 push de
 ld de,KeyLetterTable
 sbc hl,de
 ld a,l
 add a,'A'-1
 pop de
 ld (de),a
 inc de
 call _putc
CheckForMaxChar:
 ld a,(de)
 or a
 jr z,MaxCharInput
 ld a,' '
 jr EndGetNameLoop
MaxCharInput:
 ld a,$E7
EndGetNameLoop:
 ld (_curUnder),a
; ld (_textShadow+120),a
 call _putc
 ld hl,_curCol
 dec (hl)
 jr GetNameLoop

SetSpace:
 ld a,(de)
 or a
 jr z,GetNameLoop
 ld a,' '
 ld (de),a
 inc de
 call _putc
 jr CheckForMaxChar
DeleteChar:
 dec de
 ld a,(de)
 inc de
 or a
 jr z,GetNameLoop
 dec de
 ld a,' '
 ld (de),a
 call _cursorOff
 ld hl,_curCol
 call _putc
 dec (hl)
 dec (hl)
 call _putc
 dec (hl)
 call _cursorOn
 jr GetNameLoop
;
;
;
SaveTable:
 call _cursorOff
 res appTextSave,(iy+appflags)
;
;Writeback routine
; Taken from Jimmy Mardell (any program, he uses the same in all :)
;
 ld hl,_asapvar
 rst 20h
 rst 10h
 ex de,hl
 ld a,b
 ld de,HighScoreTable-$D748+4
 add hl,de
 adc a,0
 ld de,HighScoreTable
 ld b,HighScoreTableEnd-HighScoreTable
RepCopy:
 push af
 push hl
 call $46C3
 ld a,(de)
 ld (hl),a
 pop hl
 pop af
 call $4637
 inc de
 djnz RepCopy
 jp MenuSetup
;
; Sub Routines
;
;
;Menu
;
;
; Clears the _textShadow and sets cursor to top-left location of screen, and then exits back to OS/Shell
;
ExitGame:
 ld hl,_textShadow
 ld de,_textShadow+1
 ld (hl),' '
 ld bc,127
 ldir
 call _clrLCD
 res onInterrupt,(iy+onflags)
 set appTextSave,(iy+appflags)
 jp _homeup

;
; Inverts a row 16 bytes wide by 7 rows high
; HL -> Start of row address to invert
;
InvRow:
 ld b,112
 ld a,(hl)
 cpl
 ld (hl),a
 inc hl
 djnz $-4
 ret
;
; draws a 4-byte long by 7 rows high block that complements the area it is being copied to
; H = Row to change / 8
; L = Column to change / 8
; HL, DE saved
;
DrawBlock:
 push hl
 push de
 ld a,h
 add a,a
 add a,a
 add a,a
 ld h,0
 ld c,l
 ld l,a
 add hl,hl
 add hl,hl
 add hl,hl
 add hl,hl
 ld de,SCREENADDR
 add hl,de
 ld a,c
 ADD_HL_A
 ld de,13
 ld b,7
DBLoop:
 ld a,(hl)
 cpl
 ld (hl),a
 inc hl
 ld a,(hl)
 cpl
 ld (hl),a
 inc hl
 ld a,(hl)
 cpl
 ld (hl),a
 inc hl
 ld a,(hl)
 cpl
 ld (hl),a
 add hl,de
 djnz DBLoop
 pop de
 pop hl
 ret
;
DecSpeed:
 push af
 ld a,(Speed)
 inc a
 ld (Speed),a
 dec h
 jr nz,$+8
 ld h,3
 xor a
 ld (Speed),a
 pop af
 ret
IncSpeed:
 push af
 ld a,(Speed)
 dec a
 ld (Speed),a
 inc h
 cp -1
 jr nz,$+9
 ld h,1
 ld a,2
 ld (Speed),a
 pop af
 ret
ChangeTrackSize:
 ld a,e
 cp 2
 jr z,$+10
 ld e,2
 ld a,1
 ld (TrackSize),a
 ret
 ld e,10
 xor a
 ld (TrackSize),a
 ret
;
;In game
;
DecreaseLife:
 ld hl,Life
 dec (hl)
ShowLife:
 ld a,(Life)
 cp 100
 ret nc
 ld hl,SCREENADDR
 ld c,a
 rrca
 rrca
 rrca
 and %00011111
 jr z,$+8
 ld b,a
 ld (hl),0
 inc hl
 djnz $-3
 ld a,c
 and 7
 ld b,a
 ld a,$FF
 jr z,$+6
 or a
 rra
 djnz $-2
 ld (hl),a
 ld hl,SCREENADDR
 ld de,SCREENADDR+16
 ld b,5
 push bc
 ld bc,7
 ldir
 ld bc,9
 add hl,bc
 ex de,hl
 add hl,bc
 ex de,hl
 pop bc
 djnz $-14
 ret
;
ReadKeys:
 xor a
 ld (ExitPress),a
 ld hl,CarX
 ld a,%00111111
 out (1),a
 in a,(1)
 rla
 jr nc,PauseGame
 rla
 jr c,$+5
 ld (ExitPress),a
 ld a,%01111110
 out (1),a
 in a,(1)
 rra
 rra
 call nc,MoveCarLeft
 rra
 jr nc,MoveCarRight
 ret
MoveCarLeft:
 push af
 dec (hl)
 ld a,(hl)
 cp 8
 jr nc,$+3
 inc (hl)
 pop af
 ret
MoveCarRight:
 inc (hl)
 ld a,(hl)
 cp 112
 jr c,$+3
 dec (hl)
 ret
PauseGame:
 set textEraseBelow,(iy+textflags)
 ld hl,SCREENADDR
 ld de,SCREENSAVE
 ld bc,1024
 ldir
 call _getky
 ld hl,PauseText
 call _VPUTS
 call _getkey
 ld b,25
 HALT_LOOP
 ld hl,SCREENSAVE
 ld de,SCREENADDR
 ld bc,1024
 ldir
 res textEraseBelow,(iy+textflags)
 ret
;
PlaceTopRow:
 ld hl,SCREENADDR+(16*7)
 ld de,SCREENADDR+(16*7)+1
 ld (hl),$FF
 ld bc,15
 ldir
 ld a,(Wall)
 ld c,a
 rrca
 rrca
 rrca
 and %00011111
 ld b,a
 ld hl,SCREENADDR+(16*7)
 inc hl
 djnz $-1
 ld a,c
 call GetSide
 ld (hl),a
 ld a,(TrackSize)
 add a,4
 ld b,a
 inc hl
 ld (hl),0
 djnz $-3
 ld a,c
 call GetSide
 cpl
 ld (hl),a
 ret
GetSide:
 and %00000111
 ret z
 ld b,a
 xor a
 scf
 rra
 djnz $-2
 ret
MoveChange:
 ld hl,MoveDir
 ld a,(hl)
 cpl
 inc a
 ld (hl),a
 ld a,r
 rra
 and %111111
 inc a
 inc hl
 ld (hl),a
 ret
;
; checks if a pixel is on or off, Z flag set if off, reset if on
; 29 bytes | 124 cycles with "ret" (speed is static)
; (B,A) = (X,Y)
; All registered destroyed
;
CheckPixel:
 ld l,b
 rl l
 rrca
 rr l
 rrca
 rr l
 rrca
 rr l
 rrca
 rr l
 and %00001111
 add a,$FC
 ld h,a
 ld a,b
 and 7
 ld d,$C1
 ld e,a
 ld a,(de)
 and (hl)
 ret
CPBits:
 .db $80,$40,$20,$10,$08,$04,$02,$01
;
; Universal Routines
;
;Output
; HL -> High score data for current settings
GetHighScore:
 ld a,(Speed)
 add a,a
 ld b,a
 ld a,(TrackSize)
 add a,b
 add a,a
 add a,a
 ld b,a
 add a,a
 add a,b
 ld hl,HighScoreTable+1
 ADD_HL_A
 ret
;
; Fades out the screen as if blinds were closing over it
;
CloseBlinds:
 ld a,%10000000
 ld b,8
CBLoop1:
 push af
 ld de,1024
 ld hl,$FC00
DBLoop2:
 pop af
 push af
 or (hl)
 ld (hl),a
 inc hl
 dec de
 ld a,d
 or e
 jr nz,DBLoop2
 halt
 halt
 halt
 pop af
 scf
 rra
 djnz CBLoop1
 ret
;
; displays a number
;DispA:
; A = number to display
;DispHL:
; HL = number to display
;
; B = number of digits to display
; DE = location to display | (D,E) = (X,Y)
;
DispA:
 ld h,0
 ld l,a
DispHL:
 ld (_penCol),de
 ld de,ProgEnd+5
 xor a
 ld (de),a
 dec de
 call _divHLby10
 add a,'0'
 ld (de),a
 djnz $-7
 ex de,hl
 jp _vputs
;
; Strings
;
MenuText:

SpeedChooseDirections:
 .db 0,30
 .db "Choose Speed   (",$06," /",$07," )",0
TrackChooseDirections:
 .db 32,24
 .db "Choose Track Size   (",$CF,'/',$05,')',0
SpeedChoiceStrs:
 .db 8,56
 .db "Slow",0
 .db 16,51
 .db "Normal",0
 .db 24,57
 .db "Fast",0
DifficultyChoiceStrs:
 .db 40,23
 .db "Thick",0
 .db 40,89
 .db "Thin",0

HighScoreText:
 .db 56,2
 .db "High Score:",0
HighScoreTable:
 .db 0,"--------",0       ;fast + thin
 .dw 0
 .db 0,"--------",0       ;fast + thick
 .dw 0
 .db 0,"--------",0       ;normal + thin
 .dw 0
 .db 0,"--------",0       ;normal + thick
 .dw 0
 .db 0,"--------",0       ;slow + thin
 .dw 0
 .db 0,"--------",0       ;slow + thick
 .dw 0
HighScoreTableEnd:

PauseText:
 .db 29,42
 .db " Game Paused",0
CrashText:
 .db 29,44
 .db " You Crashed",0
NewHSText:
 .db 0,2
 .db "A New High Score!",0
 .db 2,3
 .db "Enter your name",0
;
; Data
;
KeyLetterTable:
 .db $2E,$26,$1E,$16,$0E
 .db $2D,$25,$1D,$15,$0D
 .db $2C,$24,$1C,$14,$0C
 .db $2B,$23,$1B,$13,$0B
 .db     $22,$1A,$12,$0A
 .db     $21,$19
;
; Sprites
;
CarSprite:
 .db 8,1
 .db %00011000
 .db %01011010
 .db %01111110
 .db %01011010
 .db %00011000
 .db %11011011
 .db %11111111
 .db %11000011
;
; Pictures
;
TitleScreen:
;
; Standard Cars title screen
;
 .db $91,$FF,$10,$FE,$00,$07,$E0,$02,$00,$03,$E0,$00,$00,$91,$FF,$06
 .db $FC,$00,$03,$C0,$00,$00,$01,$C0,$00,$00,$91,$FF,$06,$F9,$FF,$F9
 .db $9F,$FC,$FF,$FC,$9F,$FF,$FC,$F8,$91,$00,$05,$F3,$00,$0C,$30,$06
 .db $80,$06,$30,$00,$04,$F0,$41,$03,$91,$FF,$03,$E6,$FC,$06,$6E,$1B
 .db $BC,$03,$6E,$E0,$6C,$E0,$A2,$80,$91,$00,$03,$CD,$F8,$0B,$D8,$3D
 .db $B8,$0D,$DD,$C0,$D9,$CA,$22,$8F,$91,$FF,$03,$9B,$F0,$1D,$B7,$FE
 .db $B7,$FC,$BB,$81,$B3,$8A,$42,$80,$91,$00,$03,$97,$C0,$00,$A8,$1E
 .db $A8,$18,$B4,$00,$67,$04,$E9,$3F,$91,$FF,$03,$97,$BF,$FF,$AB,$EE
 .db $8B,$E2,$AB,$FF,$CE,$91,$00,$06,$97,$7F,$FF,$88,$0E,$88,$06,$9C
 .db $00,$CF,$91,$FF,$06,$97,$7F,$FF,$8F,$FE,$8D,$CE,$B8,$1F,$67,$91
 .db $FF,$06,$96,$7F,$B8,$8F,$FE,$83,$9D,$D0,$3F,$B3,$E0,$00,$3F,$91
 .db $FF,$03,$94,$7F,$53,$9F,$FC,$87,$3E,$E0,$7F,$99,$DF,$FF,$DF,$91
 .db $FF,$03,$90,$70,$0D,$B8,$08,$88,$0C,$F0,$03,$09,$BC,$FF,$EF,$91
 .db $FF,$03,$90,$44,$0D,$BB,$E0,$9B,$EA,$FF,$FC,$09,$BD,$55,$EF,$91
 .db $FF,$03,$90,$7B,$F3,$BB,$E0,$BB,$E6,$FF,$FE,$09,$BC,$E7,$EF,$91
 .db $FF,$03,$90,$7F,$FF,$83,$E0,$83,$E0,$FF,$FE,$09,$DD,$75,$DF,$91
 .db $FF,$03,$90,$BF,$91,$FF,$06,$FC,$09,$E4,$CF,$91,$00,$03,$07,$91
 .db $91,$01,$C0,$91,$00,$07,$09,$91,$FF,$05,$FB,$9B,$FE,$0F,$FE,$03
 .db $9F,$70,$3F,$C0,$19,$CF,$B7,$91,$FF,$03,$7D,$CD,$FC,$1F,$FC,$07
 .db $3E,$E0,$7F,$80,$33,$B7,$B7,$7F,$C7,$FF,$65,$E6,$F8,$3F,$F8,$0E
 .db $7D,$C0,$FF,$00,$67,$7F,$B6,$AF,$BF,$3F,$6D,$F3,$91,$00,$08,$CF
 .db $76,$B6,$67,$C6,$AD,$75,$F9,$91,$FF,$08,$9F,$76,$B6,$EB,$FA,$AD
 .db $75,$FC,$91,$00,$08,$3F,$76,$B7,$2B,$FB,$2D,$65,$FE,$91,$00,$08
 .db $7F,$70,$93,$FB,$87,$E1,$3D,$91,$FF,$0A,$BF,$91,$FF,$04,$FB,$91
 .db $FF,$0A,$C0,$91,$00,$04,$07,$91,$FF,$24,$FE,$7F,$91,$FF,$06,$EF
 .db $FF,$FF,$F9,$91,$FF,$04,$F8,$01,$91,$FF,$06,$D0,$00,$00,$05,$91
 .db $FF,$04,$E0,$00,$01,$91,$FF,$05,$AF,$DF,$FF,$EB,$91,$FF,$04,$80
 .db $00,$FE,$03,$91,$FF,$04,$5F,$AF,$FF,$D7,$91,$FF,$03,$FE,$00,$03
 .db $FF,$C0,$03,$91,$FF,$03,$3F,$53,$FF,$8F,$7F,$FF,$FF,$FD,$C0,$0F
 .db $FF,$91,$00,$04,$1F,$80,$54,$00,$3F,$07,$FF,$F0,$03,$F8,$1F,$FC
 .db $00,$07,$FE,$00,$FF,$F7,$76,$FA,$FF,$00,$00,$0F,$F8,$07,$7F,$F0
 .db $00,$3F,$FC,$03,$FF,$F0,$8B,$00,$7F,$00,$3F,$FF,$FF,$F8,$0F,$FC
 .db $00,$3F,$F8,$07,$FF,$F9,$FB,$4F,$FF,$00,$00,$FF,$FF,$00,$00,$03
 .db $FF,$FF,$F0,$07,$FF,$F5,$9D,$AF,$FF,$00,$00,$1F,$C0,$00,$00,$1F
 .db $FF,$9F,$C0,$0F,$E0,$73,$0D,$F6,$03,$00,$00,$60,$91,$00,$03,$FF
 .db $FF,$07,$00,$1F,$C0,$AA,$CD,$F4,$03,$00,$7F,$FE,$00,$00,$03,$FF
 .db $FE,$00,$C0,$1F,$C1,$DF,$EF,$F8,$05,$0F,$91,$FF,$03,$00,$0F,$FF
 .db $FC,$00,$3F,$BF,$81,$B8,$FF,$F8,$05,$91,$FF,$05,$BF,$FF,$F8,$00
 .db $07,$BF,$81,$70,$3F,$F8,$05,$91,$FF,$04,$FC,$03,$FF,$F0,$00,$1B
 .db $7F,$A8,$F7,$5F,$F2,$A5,$91,$FF,$04,$C0,$00,$3F,$E0,$00,$1D,$7F
 .db $90,$E6,$5F,$C9,$55,$07,$FF,$FF,$F8,$00,$00,$03,$C0,$00,$60,$FF
 .db $A5,$E8,$9F,$82,$A5,$00,$0F,$FC,$91,$00,$06,$FF,$FF,$B5,$C2,$7F
 .db $BB,$F5,$91,$00,$07,$60,$00,$FF,$FF,$D3,$8D,$FF,$BB,$F5,$00,$00
 .db $78,$91,$00,$04,$FC,$00,$FF,$FF,$DB,$9D,$FF,$85,$FB,$00,$0F,$FF
 .db $80,$00,$00,$01,$FF,$81,$FF,$FF,$E7,$33,$FC,$3E,$03,$1F,$FF,$FF
 .db $F8,$00,$00,$07,$FF,$E1,$FF,$E0,$F7,$2F,$E0,$3F,$91,$FF,$05,$80
 .db $00,$3F,$FF,$FD,$FF,$C3,$6F,$1F,$D0,$1F,$EF,$3F,$91,$FF,$03,$F0
 .db $00,$FF,$FF,$FB,$FF,$87,$AF,$FF,$A0,$5F,$D3,$07,$91,$FF,$04,$DF
 .db $FF,$FF,$FB,$FF,$87,$8F,$F7,$60,$5F,$AD,$00,$91,$FF,$04,$8F,$FF
 .db $FF,$FB,$FF,$A7,$47,$C6,$AA,$5F,$5A,$00,$3F,$FF,$FF,$FC,$01,$FF
 .db $FF,$F7,$FF,$94,$1F,$F8,$05,$5E,$AA,$00,$0F,$FF,$FF,$F0,$00,$3F
 .db $FF,$F7,$FF,$B6,$1E,$00,$0F,$5D,$02,$00,$03,$FF,$FF,$80,$00,$0F
 .db $FF,$EF,$FF,$B7,$6D,$F7,$EF,$5E,$EA,$00,$00,$FF,$FC,$00,$00,$03
 .db $FF,$DF,$FF,$DB,$00,$0F,$F7,$9F,$2A,$00,$00,$1F,$E0,$91,$00,$03
 .db $FF,$BF,$FF,$E0,$FF,$FF,$F8,$3F,$D5,$00,$00,$03,$80,$91,$00,$03
 .db $1F,$7F,$91,$FF,$06,$EB
;
; Christmas Cars Title Screen
;
; .db $FF,$E0,$FF,$FB,$01,$E9,$FF,$7A,$07,$FF,$DF,$91,$FF,$05,$FE,$00
; .db $07,$E0,$00,$00,$02,$60,$00,$00,$FE,$F0,$1F,$EF,$F7,$FB,$E4,$00
; .db $03,$C0,$91,$00,$06,$FF,$C0,$0F,$FF,$FF,$F1,$E1,$FF,$F9,$9F,$FC
; .db $FF,$FC,$1F,$FF,$FC,$B8,$91,$00,$05,$C3,$00,$0C,$30,$06,$80,$06
; .db $30,$00,$04,$E0,$41,$02,$3F,$FF,$E3,$86,$FC,$06,$6E,$1B,$BC,$03
; .db $6E,$E0,$6C,$80,$A2,$80,$91,$00,$03,$8D,$F8,$0B,$D8,$3D,$B8,$0D
; .db $DD,$C0,$D9,$0A,$22,$88,$6F,$B3,$BF,$9B,$F0,$1D,$B7,$FE,$B7,$FC
; .db $BB,$81,$B2,$0A,$42,$80,$91,$00,$03,$97,$C0,$00,$A8,$1E,$A8,$18
; .db $B4,$00,$66,$04,$E9,$3D,$FF,$87,$FF,$97,$BF,$FF,$AB,$EE,$8B,$E2
; .db $AB,$FF,$CE,$91,$00,$06,$97,$7F,$FF,$88,$0E,$88,$06,$9C,$00,$CD
; .db $FF,$FF,$F7,$91,$FF,$03,$97,$7F,$FF,$8F,$FE,$8D,$CE,$B8,$1F,$67
; .db $91,$FF,$05,$FD,$96,$7F,$B8,$8F,$FE,$83,$9D,$D0,$3F,$B3,$E0,$00
; .db $3F,$DF,$DF,$FF,$94,$7F,$53,$9F,$FC,$87,$3E,$E0,$7F,$99,$DF,$FF
; .db $DF,$91,$FF,$03,$90,$70,$0D,$B8,$08,$88,$0C,$F0,$03,$09,$BC,$FF
; .db $EF,$91,$FF,$03,$90,$44,$0D,$BB,$E0,$9B,$EA,$FF,$FC,$09,$BD,$55
; .db $EE,$FD,$FF,$FF,$90,$7B,$F3,$BB,$60,$BA,$66,$E1,$FE,$09,$BC,$E7
; .db $EF,$FF,$FF,$BF,$90,$7F,$FF,$83,$A0,$82,$20,$80,$7E,$09,$DD,$75
; .db $DF,$91,$FF,$03,$90,$BF,$91,$FF,$06,$FC,$09,$E4,$CF,$91,$00,$03
; .db $07,$91,$91,$01,$C0,$91,$00,$07,$09,$91,$FF,$05,$FB,$9B,$FE,$0F
; .db $FE,$03,$9F,$70,$3F,$C0,$19,$CF,$B7,$91,$FF,$03,$7D,$CD,$FC,$1F
; .db $FC,$07,$3E,$E0,$7F,$80,$33,$B7,$B7,$7F,$C7,$FF,$65,$E6,$F8,$3F
; .db $F8,$0E,$7D,$C0,$FF,$00,$67,$7F,$B6,$AF,$BF,$3F,$6D,$F3,$91,$00
; .db $08,$CF,$76,$B6,$67,$C6,$AD,$75,$D9,$91,$FF,$08,$9F,$76,$B6,$EB
; .db $FA,$AD,$75,$FC,$91,$00,$08,$3F,$76,$B7,$2B,$FB,$2D,$65,$FE,$91
; .db $00,$08,$7F,$70,$93,$FB,$87,$E1,$3D,$91,$FF,$09,$F7,$BF,$91,$FF
; .db $04,$FB,$FB,$91,$FF,$05,$EF,$91,$FF,$03,$C0,$91,$00,$04,$07,$FF
; .db $FF,$BF,$FF,$7F,$FB,$FF,$DF,$91,$FF,$09,$DF,$91,$FF,$09,$FD,$91
; .db $FF,$03,$7F,$91,$FF,$03,$DF,$FE,$7F,$FF,$FF,$7F,$7D,$FF,$FF,$EC
; .db $7E,$FE,$39,$91,$FF,$04,$F8,$01,$FF,$F7,$FF,$FF,$FB,$FF,$D0,$00
; .db $00,$05,$91,$FF,$04,$E0,$00,$01,$FF,$FF,$FB,$FF,$FF,$A8,$DC,$1F
; .db $EB,$FF,$FF,$7F,$FF,$80,$00,$FE,$03,$91,$FF,$04,$5B,$AF,$02,$D7
; .db $91,$FF,$03,$FE,$00,$03,$FF,$C0,$03,$91,$FF,$03,$3F,$53,$8F,$8F
; .db $7F,$FF,$FF,$FD,$C0,$0F,$FF,$91,$00,$04,$1F,$80,$54,$00,$3F,$07
; .db $FF,$F0,$03,$F8,$1F,$FC,$00,$07,$FE,$00,$FE,$F7,$76,$FA,$FF,$00
; .db $00,$0F,$F8,$07,$7F,$F0,$00,$3F,$FC,$03,$FF,$F0,$8B,$00,$69,$00
; .db $3F,$FF,$FF,$F8,$0F,$FC,$00,$3F,$F8,$07,$F9,$F9,$FB,$4F,$CD,$00
; .db $00,$FF,$FF,$00,$00,$03,$FF,$FF,$F0,$07,$F0,$F5,$9D,$AF,$07,$00
; .db $00,$1F,$C0,$00,$00,$1F,$FF,$9F,$C0,$0E,$E0,$73,$0D,$F6,$03,$00
; .db $00,$60,$91,$00,$03,$FF,$FF,$07,$00,$1F,$C0,$AA,$CD,$F4,$03,$00
; .db $7F,$FE,$00,$00,$03,$FF,$FE,$00,$C0,$1F,$C1,$DF,$EF,$F8,$05,$0F
; .db $91,$FF,$03,$00,$0F,$FF,$FC,$00,$3F,$BF,$81,$B8,$FE,$78,$05,$91
; .db $FF,$05,$BF,$FF,$F8,$00,$07,$BF,$81,$10,$3C,$F8,$05,$91,$FF,$04
; .db $FC,$03,$FF,$F0,$00,$1B,$7F,$A8,$37,$58,$F2,$A5,$91,$FF,$04,$C0
; .db $00,$3F,$E0,$00,$1D,$7F,$90,$66,$59,$C9,$55,$07,$FF,$FF,$F8,$00
; .db $00,$03,$C0,$00,$60,$ED,$A4,$68,$93,$82,$A5,$00,$0F,$FC,$91,$00
; .db $06,$FF,$FF,$B4,$C2,$67,$BB,$F5,$91,$00,$07,$60,$00,$FF,$FF,$D0
; .db $8D,$EF,$BB,$F5,$00,$00,$78,$91,$00,$04,$FC,$00,$FE,$F9,$D9,$9D
; .db $FF,$85,$FB,$00,$0F,$FF,$80,$00,$00,$01,$FF,$81,$DF,$F1,$E5,$33
; .db $3C,$3E,$03,$1F,$FF,$FF,$F8,$00,$00,$07,$FF,$E1,$FF,$E0,$F1,$2F
; .db $60,$3E,$91,$FF,$05,$80,$00,$3F,$FF,$FD,$FF,$C3,$65,$1F,$D0,$1F
; .db $EF,$3F,$91,$FF,$03,$F0,$00,$FF,$FF,$FB,$F7,$87,$A1,$FF,$A0,$5F
; .db $D3,$07,$91,$FF,$04,$DF,$FF,$FF,$FB,$FF,$87,$89,$F7,$60,$5B,$AD
; .db $00,$91,$FF,$04,$8F,$FF,$FF,$FB,$FF,$A7,$44,$C6,$AA,$5F,$5A,$00
; .db $3F,$FF,$FF,$FC,$01,$FF,$FF,$F7,$FF,$94,$1F,$F8,$05,$5E,$AA,$00
; .db $0F,$FF,$FF,$F0,$00,$3F,$FF,$F7,$FF,$B6,$1E,$00,$0F,$5D,$02,$00
; .db $03,$FF,$FF,$80,$00,$0F,$FF,$EF,$B7,$B7,$6D,$F7,$EF,$5E,$EA,$00
; .db $00,$FF,$FC,$00,$00,$03,$FF,$DD,$FF,$DB,$00,$0F,$77,$9F,$2A,$00
; .db $00,$1F,$E0,$91,$00,$03,$FF,$BF,$FF,$E0,$FF,$FF,$F8,$3F,$D5,$00
; .db $00,$03,$80,$91,$00,$03,$1F,$7F,$FD,$91,$FF,$03,$BF,$FF,$EB
;
#include "DispStr.h"
#include "CarsFS.h"
#include "rle.h"

ProgEnd:

.end
